@@ -27,9 +27,9 @@
 
 #include <tools.h>
 
-#include <QtCore/QList>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
+#include <QList>
+#include <QString>
+#include <QStringList>
 
 namespace Syndication
 {
