@@ -23,7 +23,7 @@
 #include "category.h"
 #include "tools.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace Syndication
 {
